# -*- coding: iso-8859-1 -*-
"""
    MoinMoin - Bug Macro 
    
    @copyright: 2008 Ubuntu-it - Developed by Alessio Treglia <quadrispro@ubuntu.com>.
    @license: GNU GPL, see COPYING for details.
"""

from MoinMoin import config, wikiutil

projects = {
    "ubuntu"    : "https://bugs.launchpad.net/ubuntu/+bug/%d",
    "debian"	: "http://bugs.debian.org/cgi-bin/bugreport.cgi?bug=%d",
    "gnome"     : "http://bugzilla.gnome.org/show_bug.cgi?id=%d",
    "kde"       : "http://bugs.kde.org/show_bug.cgi?id=%d",
    "xfce"      : "http://bugzilla.xfce.org/show_bug.cgi?id=%d",
    "kernel"	: "http://bugzilla.kernel.org/show_bug.cgi?id=%d"
    }

projects_emblems = {
    "ubuntu"    : "https://launchpadlibrarian.net/9608570/ubuntu_emblem.png",
    "debian"	: "http://www.debian.org/favicon.ico",
    "gnome"     : "https://launchpadlibrarian.net/11396521/gnome.png",
    "kde"       : "https://launchpadlibrarian.net/7101115/klogo-official-crystal-14.png",
    "xfce"      : "https://launchpadlibrarian.net/4040580/mouse.png",
    "kernel"	: "http://www.kernel.org/favicon.ico"
    }

def NoProjectSelectedException(Exception):
    """
    The macro raises an instance of this exception
    when the argument doesn't contain any project
    valid name.
    """
    def __init__(self, message):
        """
        Default __init__ method.
        """
        Exception.__init__(self, message)

def args_to_dict(args):
    """
    This method converts a string in a dictionary.
    It uses project's name (if valid) as key, and
    a list of bug ids as value.
    For example:

    The call:

    args_to_dict("gnome 3 4 6 ubuntu 1 9 6 kde 7 xfce")

    returns:

    {'kde': [7], 'xfce': [], 'gnome': [3, 4, 6], 'ubuntu': [1, 9, 6]}
    """
    args_dict = dict()
    project_selected = None
    for i in projects.keys():
        args_dict[i] = list()
    if args:
        args_list = args.split()
        for cur in args_list:
            if cur in projects.keys():
                project_selected = cur
            elif project_selected != None:
                try:
                    args_dict[project_selected].append(int(cur))
                except ValueError:
                    raise ValueError #, u"Carattere non valido, i bug devono essere indicati con numeri interi: %s"
            else:
                raise NoProjectSelectedException, u"Nessun progetto selezionato per i bug elencati: %s"
    return args_dict

def execute(macro,args):
    """
    Execute method. It formats and returns
    the result.
    """
    request=macro.request
    formatter=macro.formatter
    result=""
    try:
        args_dict = args_to_dict(args)
    except ValueError, e:
        raise ValueError(e.message % args)
    except NoProjectSelectedException, e:
        raise NoProjectSelectedException(e.message % args)
    for i in args_dict.keys(): # i = current project
        for j in args_dict[i]: # j = current bug id
            result += u'<img src="%s" />' % projects_emblems[i]
            # result+='<img src="https://launchpadlibrarian.net/7094128/launchpad-icon.png" /> '
            # result+=formatter.url(on=1,url="http://launchpad.net/bugs/%s" % i)
            result+=formatter.url(on=1,url=projects[i] % j)
            result+=u"#%d" % j
            result+=formatter.url(on=0)
            result+=" "
    return result

"""
Alternative args2dict converter.

It gets a string with a syntax like this:

args_to_dict('gnome=4 6 2 ubuntu=3 8 91 xfce=92 1237')

It returns:

{'kde': [], 'xfce': [92, 1237], 'gnome': [4, 6, 2], 'ubuntu': [3, 8, 91]}

def args_to_dict(args):
	args_dict = dict()
	project_selected = None
	cur_word = ''
	for i in projects.keys(): # initialize the dictionary
		args_dict[i] = []
	for i in args: # for each character
		if i is '=':
			if cur_word in projects.keys():
				project_selected = cur_word
				cur_word = '' # parse the next word
			else: # there's a syntax error
				raise SyntaxException, "Sintassi non corretta"
		elif i is ' ': # space char is a particular case
			if project_selected and cur_word and cur_word is not ' ':
                                try:
                                        args_dict[project_selected].append(int(cur_word))
                                        cur_word = ''
                                except ValueError:
                                        pass # skip space char
		else: # add the char to the word
			cur_word += i
	# this is for the last word
	if project_selected and cur_word:
		args_dict[project_selected].append(int(cur_word))
		
	return args_dict # end
"""

