# -*- coding: iso-8859-1 -*-
"""
    MoinMoin - Informazioni Macro 
    
    @copyright: 2009 Ubuntu-it - Leo Iannacone <l3on@ubuntu.com>.
"""

from MoinMoin import config, wikiutil


# Formato:
# Informazioni(help="link", forum="link", rilasci="9.10 8.10")

header = '''
	<div class="page_info">
		<div class="toc-top-sx"> </div>
		<div class="toc-top-dx"> </div>
		<div> <!-- Just for IE -->
			<div class="page_info-core">
	
	'''
footer = '''
			</div> <!-- Closing "page_info-core" -->
		</div> <!-- Closing IE's div -->
		<div class="toc-bottom-sx"> </div>
		<div class="toc-bottom-dx"> </div>
	</div> <!-- Closing "page_info" -->
	'''

usage = '''

Utilizzare la macro in questo modo:\n\n\n\t
	[[Informazioni(help="link nella documentazione ufficiale"; forum="link alla discussione del forum su questa pagina"; rilasci="9.10 8.10 ... etc...")]]
	'''

def from_args_to_dict(args):
	info = args.split(';')
	result = {}
	for arg in info:
		arg = arg.strip()
		if len(arg) > 0:
			sub_info = arg.split("=")
			try:
				result[sub_info[0].strip()] = sub_info[1].replace('"','').replace("'",'').strip()
			except:
				raise Exception('ExceptionArguments: l\'argomento %s non e\' valido!\n\n%s' % (arg, usage))
	return result


def execute(self, args):
	if len(args) is 0:
		return ''
	dict_args = from_args_to_dict (args)
	self.result = []
	self.result.append(header)
	found = False

	for arg in dict_args:
		if arg not in ['rilasci', 'forum', 'help']:
			raise Exception ('ExceptionArguments: l\'argomento "%s" non e\' valido!\n\n%s' % (arg, usage))
	
	if 'rilasci' in dict_args:
		self.result.append(releases(dict_args['rilasci']))
	if 'forum' in  dict_args:
		self.result.append(forum(self, dict_args['forum']))
	if 'help' in  dict_args:
		self.result.append(help(self, dict_args['help']))

	self.result.append(footer)
	return ''.join(self.result)

def forum(self, args):

	if not (args.find('forum.ubuntu-it.org') is 0 or args.find('forum.ubuntu-it.org') is 7) or len(args.split()) > 1:
		raise Exception ('ExceptionArguments: l\'argomento %s non e\' un valido link al forum di ubuntu-it.\n\n%s' % (args, usage))
	if not args.find('http://') is 0:
		args = 'http://%s' % args
	return '<p class="forum">Per problemi in questa pagina, contatta il Gruppo Documentazione in %squesta discussione%s.</p>' % (self.formatter.url(on=1, url=args), self.formatter.url(on=0))


def help(self, args):
	if not (args.find('help.ubuntu-it.org') is 0 or args.find('help.ubuntu-it.org') is 7) or len(args.split()) > 1:
		raise Exception ('ExceptionArguments: l\'argomento %s non e\' un valido link alla documentazione ufficiale.\n\n%s' % (args, usage))
	if not args.find('http://') is 0:
		args = 'http://%s' % args
	return '<p class="help">Questa guida &egrave presente anche nella %sdocumentazione ufficiale%s.</p>' % (self.formatter.url(on=1, url=args), self.formatter.url(on=0))


def releases(args):

	if args == '':
      		raise Exception('ExceptionArguments - Rilasci: inserire il nome di almeno un rilascio di Ubuntu nella macro VersioniSupportate. %s ' % usage)

	result = []

	pageRelease = {
		'6.06': "DapperNoteDiRilascio",
		'7.04': "FeistyNoteDiRilascio",
		'7.10': "GutsyNoteDiRilascio",
		'8.04': 'HardyNoteDiRilascio',
		'8.10': 'IntrepidNoteDiRilascio',
		'9.04': 'JauntyNoteDiRilascio',
		'9.10': 'KarmicNoteDiRilascio',
		'10.04': 'LucidNoteDiRilascio',
    '10.10': 'Ubuntu+1'
	}

	nameRelease = {
		'puppa': 'easteregg',
		'4.10': 'deprecated',
		'5.04': 'deprecated',
		'5.10': 'deprecated',
		'6.06': "Dapper Drake",
		'6.10': 'deprecated',
		'7.04': 'deprecated',
		'7.10': 'deprecated',
		'8.04': 'Hardy Heron',
		'8.10': 'deprecated',
		'9.04': 'Jaunty Jackalope',
		'9.10': 'Karmic Koala',
		'10.04': 'Lucid Lynx',
    '10.10': 'Maverick Meerkat'
	}


	# Preparing to cycle
	result.append('<p class="releases">Versioni supportate: ')

	# Just a bool to check if there are some releases in macro. 
	has_releases = False


	# Cycling args
	for arg in args.split():
		# If it's a typing mistake
		if arg not in nameRelease:
			raise Exception('ExceptionRelease - Rilasci: Attenzione il rilascio "%s" non esiste.'%  arg )
		# If it's deprecated
		if nameRelease[arg] == 'deprecated':
			continue
		# If it's unstable
		#if nameRelease[arg] == 'unstable':
		#raise Exception('ExceptionRelease - VersioniSupportate: E\' vietato inserire la release "%s" poiche\' e\' ancora in fase di sviluppo.' % arg )
		# Smile, it's a simple easteregg
		if nameRelease[arg] == 'easteregg':
			raise Exception('ExceptionRelease: le prestazioni sessuali di MiloCasagrande nei confronti di AlessioTreglia non sono state convincenti per avere il rilascio di "%s".'%  arg )
		else:
			result.append('<a title="Nome in codice: %s" href="/%s">%s</a> ' % (nameRelease[arg], pageRelease[arg], arg))
			has_releases = True


	# If there are no releaes, do nothing.
	if has_releases is False:
		return ''
	result.append('</p>')
	return ''.join(result)

