from MoinMoin.multiconfig import DefaultConfig

# Append to the global default url_schemas list. MoinMoin doesn't support this
# per wiki which is why this hack exists.
from MoinMoin.config import url_schemas
url_schemas.append('apt')


class Config(DefaultConfig):

	# Wiki identity ----------------------------------------------------

	sitename = u'Wiki di ubuntu-it'

	logo_string = sitename

	interwikiname = None

	# Critical setup  ---------------------------------------------------

	data_dir = '/srv/wiki.ubuntu-it.org/www/data/'

	data_underlay_dir = '/srv/wiki.ubuntu-it.org/www/underlay/'

	url_prefix = '/htdocs'
    
	# Security ----------------------------------------------------------

	superuser = ["MatthewEast", "MiloCasagrande", "LeoIannacone", "AlessioTreglia"]

	allowed_actions = ['AttachFile', 'DeletePage', 'RenamePage']

	acl_enabled = 1

	acl_rights_valid = ["read", "write", "revert", "delete", "admin"]

	# Use this for locking the wiki
	# acl_rights_before = u"All:read"
	# page_header1 = "<p align=\"center\"><b>Il wiki &egrave; in fase di manutenzione, per cui &egrave consultabile in sola lettura.</b></p>"

	acl_rights_before = (u"GruppoAdmin:admin,revert,delete,read,write " u"GruppoEditori:read,write,revert,delete ")

	acl_rights_default = (u"Known:read,write,revert " u"All:read ")

	# Spam protection
	# added by Milo
	# Disabled on 19/07/07
	# from MoinMoin.util.antispam import SecurityPolicy

	# Mail --------------------------------------------------------------
    
	mail_smarthost = "localhost"

	# The return address, e.g "My Wiki <noreply@mywiki.org>"
	mail_from = "Ubuntu-it Wiki <nonrispondere@ubuntu-it.org>"

	mail_login = ""

	# User interface ---------------------------------------------------=
	# Modified by Milo: set Documentazione as front_page
	page_front_page = u"Documentazione"
    
	navi_bar = [
		# Will use page_front_page, (default FrontPage)
		#u'%(page_front_page)s',
		u'[Documentazione/Indice Indice]',
		u'ModificheRecenti',
	        u'CercaPagina',
	        u'GuidaWiki',
	    ]

	theme_default = 'ubuntu-it'
    
	# Language options --------------------------------------------------

	language_default = 'it'

	# You must use Unicode strings here [Unicode]
	page_category_regex = u'^Category[A-Z]'
	page_dict_regex = u'[a-z]Dict$'
	page_form_regex = u'[a-z]Form$'
	page_group_regex = u'^Gruppo[A-Z]|^Gruppo[a-z]|^[a-z]Gruppo$'
	page_template_regex = u'[a-z]Modello$'

	# Content options ---------------------------------------------------
	# Overwritten by themefunciont
	html_head = '''
<link rel="shortcut icon" href="/htdocs/favicon.ico">
<!--[if lte IE 6]> <link rel="stylesheet" href="/htdocs/common/css/msie.css" /> <![endif]-->

'''

	#Show login options
	show_login = 1
	
	# Show users hostnames in RecentChanges
	show_hosts = 1                  

	# Enumerate headlines?
	show_section_numbers = 0

	# Charts size, require gdchart (Set to None to disable).
	chart_options = {'width': 600, 'height': 300}   

	#Enable the use of refresh (see HelpOnProcessingInstructions)
	refresh = (4, 'external')

	# Whatever footer or theme license, comment out these two
	# for showing a link to the license page during editing
	page_license_enabled = 1
	page_license_page = u"LicenzaContenuti"

	# Time format for the italian standard
	# Used in default values
	datetime_fmt = '%d/%m/%Y %H.%M.%S'
	date_fmt = '%d/%m/%Y'
	changed_time_fmt = '%H.%M'

	# Offset for the italian hour from UTC
	# Used in default values
	tz_offset = 1.0

	# Page locking for editing
	# Users are warned
	edit_locking = 'lock 5'
	
	# Force to use text editor
	editor_default='text'
	editor_force= True
	editor_ui = 'theonepreferred'
	
	# Surge protection details
	# Looks like people are experiencing this: http://moinmo.in/MoinMoinBugs/UnwantedSurgeProtection
	surge_action_limits = None
	surge_lockout_time = 0 # need testing!

	# Deny some host for spam protection, all Chinese
	hosts_deny = ['218.13.64.', '58.24.106.', '122.194.153.', '219.143.149.', '218.57.66.', '58.61.82.', '58.60.56.', '59.173.227.', '60.186.25.', '218.57.64.', '219.157.173.', '218.19.2.', '219.143.129.', '222.95.175.', '58.242.201.', '123.148.7', '220.250.8.', '58.22.140.', '222.66.55.', '60.21.3.', '61.191.23.', '58.49.116.', '220.174.65.', '125.122.63.', '218.106.149.', '218.57.65.', '61.45.185.', '221.237.86.', '121.204.191.', '58.49.114.', '221.0.161.', '125.77.143.', '125.120.7.', '221.233.71.', '123.116.154.', '59.40.100.', '219.130.166.', '59.57.166.', '219.133.204.', '222.187.247.', '125.122.55.', '222.187.235.', '55.204.133.', '58.242.200.', '58.24.111.', '125.122.57.', '222.95.173.', '219.133.205.', '121.63.178.', '61.173.79.', '221.237.64.', '125.122.56.', '222.187.237.', '124.129.109.', '116.18.80.', '219.130.118.', '58.242.207.', '61.145.184.', '59.61.47.', '58.61.83.', '125.120.18.', '222.65.243.', '221.237.78.', '221.237.66.', '124.93.155.', '222.95.175.', '202.103.156.', '59.40.40.', '123.114.43.', '58.61.23.', '125.122.21.', '60.21.1.', '59.40.39.', '125.33.207.', '125.120.17.', '219.134.239.', '121.204.156.', '59.40.42.', '116.24.117.', '59.172.117.', '124.203.169', '210.192.126.', '219.143.131.', '219.143.139.', '219.143.141.', '219.143.142.', '220.115.32.', '123.112.224.', '221.216.0.', '222.183.0.', '59.44.38.', '221.71.64.', '58.241.180.', '202.46.224.', '125.77.188.','124.129.108.', '116.3.125.', '222.248.237.', '58.24.110.', '125.120.99.', '202.105.128.', '222.248.226.', '117.8.179.', '218.107.139.', '125.90.7.','208.85.179.','213.155.0.', '78.46.98.']

